<?php

namespace Drupal\eca_condition\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Eca condition settings for this site.
 */
class ConditionSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'eca_condition_condition_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['eca_condition.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['conditions'] = [
      '#type' => 'textarea',
      '#required' => FALSE,
      '#title' => $this->t('Condtions'),
      '#description' => $this->t('Config condition with format key|value'),
      '#cols' => 60,
      '#rows' => 5,
      '#default_value' => $this->config('eca_condition.settings')->get('conditions_text'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $lines = preg_split("/\r?\n/", $form_state->getValue('conditions'));
    $conditions = [];
    foreach ($lines as $line) {
      $parts = explode('|', $line, 2);
      if (count($parts) == 2) {
        $conditions[$parts[0]] = $parts[1];
      }
    }
    $this->config('eca_condition.settings')
      ->set('conditions', $conditions)
      ->set('conditions_text', $form_state->getValue('conditions'))
      ->save();
    \Drupal::service('plugin.manager.condition')->clearCachedDefinitions();
    parent::submitForm($form, $form_state);
  }

}
