<?php

namespace Drupal\eca_condition\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eca_condition\Events\ConditionEvent;

/**
 * Provides a 'Taxonomy Vocabulary' condition.
 *
 * @Condition(
 *   id = "eca_condition",
 *   label = @Translation("ECA Condition"),
 *   deriver = "Drupal\eca_condition\Plugin\Derivative\ECAConditionDerivative"
 * )
 */
class ECACondition extends ConditionPluginBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return ['use_eca_condition' => ''] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function evaluate() {
    if (empty($this->configuration['use_eca_condition']) && !$this->isNegated()) {
      return TRUE;
    }
    if (!empty($this->configuration['use_eca_condition'])) {
      $conditionEvent = new ConditionEvent($this->getDerivativeId());
      \Drupal::service('event_dispatcher')->dispatch($conditionEvent, ConditionEvent::CONDITION_EVENT);
      return $conditionEvent->getResult();
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['use_eca_condition'] = [
      '#type' => 'select',
      '#required' => FALSE,
      '#title' => $this->t('Use this ECA condition'),
      '#default_value' => $this->configuration['use_eca_condition'] ?? '',
      '#empty_value' => '',
      '#options' => [
        1 => $this->t('Yes'),
      ],
    ];

    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['use_eca_condition'] = $form_state->getValue('use_eca_condition');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    return $this->getPluginDefinition()['label'];
  }

}
