<?php

namespace Drupal\eca_condition\Plugin\ECA\Event;

use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Entity\Objects\EcaEvent;
use Drupal\eca\Event\Tag;
use Drupal\eca\Plugin\ECA\Event\EventBase;
use Drupal\eca_condition\Events\ConditionEvent;

/**
 * Plugin implementation of the ECA Condition for config.
 *
 * @EcaEvent(
 *   id = "eca_condition",
 *   deriver = "Drupal\eca_condition\Plugin\ECA\Event\ECAConditionEventDeriver"
 * )
 */
class ECAConditionEvent extends EventBase {

  /**
   * {@inheritdoc}
   */
  public static function definitions(): array {
    return [
      'eca_condition' => [
        'label' => t('ECA Condition'),
        'event_name' => ConditionEvent::CONDITION_EVENT,
        'event_class' => ConditionEvent::class,
        'tags' => Tag::RUNTIME,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    if ($this->eventClass() === ConditionEvent::class) {
      $values = [
        'condition_id' => '',
      ];
    }
    else {
      $values = [];
    }
    return $values + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    if ($this->eventClass() === ConditionEvent::class) {
      $conditions = \Drupal::service('config.factory')->get('eca_condition.settings')->get('conditions');
      $form['condition_id'] = [
        '#type' => 'select',
        '#required' => FALSE,
        '#title' => $this->t('Condition Id'),
        '#default_value' => $this->configuration['condition_id'],
        '#empty_option' => $this->t('- Select -'),
        '#empty_value' => '',
        '#options' => $conditions ?? [],
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::submitConfigurationForm($form, $form_state);
    if ($this->eventClass() === ConditionEvent::class) {
      $this->configuration['condition_id'] = $form_state->getValue('condition_id');
    }
  }

  /**
   * {@inheritdoc}
   */
  public function lazyLoadingWildcard(string $eca_config_id, EcaEvent $ecaEvent): string {
    switch ($this->getDerivativeId()) {

      case 'eca_condition':
        $configuration = $ecaEvent->getConfiguration();
        return isset($configuration['condition_id']) ? trim($configuration['condition_id']) : '';

      default:
        return parent::lazyLoadingWildcard($eca_config_id, $ecaEvent);

    }
  }

}
